@@ -598,16 +598,13 @@ class Account(ActivePeriodMixin, tree(), ModelSQL, ModelView):
         domain=[
             ('company', '=', Eval('company')),
             ], depends=['kind', 'company'])
-    parent = fields.Many2One('account.account', 'Parent', select=True,
-        left="left", right="right", ondelete="RESTRICT",
-        domain=[('company', '=', Eval('company'))],
-        states=_states, depends=['company'])
+    parent = fields.Many2One(
+        'account.account', 'Parent', select=True,
+        left="left", right="right", ondelete="RESTRICT", states=_states)
     left = fields.Integer('Left', required=True, select=True)
     right = fields.Integer('Right', required=True, select=True)
     childs = fields.One2Many(
-        'account.account', 'parent', 'Children',
-        domain=[('company', '=', Eval('company'))],
-        depends=['company'])
+        'account.account', 'parent', 'Children')
     balance = fields.Function(fields.Numeric('Balance',
         digits=(16, Eval('currency_digits', 2)), depends=['currency_digits']),
         'get_balance')
@@ -1328,7 +1325,7 @@ class GeneralLedgerAccount(ActivePeriodMixin, ModelSQL, ModelView):
 
         period = None
         if name.startswith('start_'):
-            period_ids = [0]
+            period_ids = []
             if context.get('start_period'):
                 period = Period(context['start_period'])
         elif name.startswith('end_'):
@@ -1354,7 +1351,10 @@ class GeneralLedgerAccount(ActivePeriodMixin, ModelSQL, ModelView):
     def get_dates(cls, name):
         context = Transaction().context
         if name.startswith('start_'):
-            return None, context.get('from_date')
+            from_date = context.get('from_date')
+            if from_date:
+                from_date -= datetime.timedelta(days=1)
+            return None, from_date
         elif name.startswith('end_'):
             return None, context.get('to_date')
         return None, None
